@@ -17,6 +17,7 @@
 #include "ldastoolsal/unordered_map.hh"
 #include "ldastoolsal/ldasexception.hh"
 #include "ldastoolsal/Thread.hh"
+#include "ldastoolsal/Singleton.hh"
 
 #include "Thread.icc"
 
@@ -49,6 +50,7 @@ wakeup( int SignalNumber )
 }
 
 class thread_registry
+  : public LDASTools::AL::Singleton< thread_registry >
 {
 public:
   typedef Thread::thread_type::handle_type	key_type;
@@ -74,25 +76,18 @@ private:
 #endif /* NEEDED_PTHREAD__T_HASH_FUNC */
 			 > thread_registry_type;
 
-  inline static thread_registry_type
-  storage( )
-  {
-    static thread_registry_type    m_storage;
+  MutexLock::baton_type	__baton__;
+  thread_registry_type  m_storage;
 
-    return m_storage;
-  }
-
-  inline static MutexLock::baton_type
-  baton( )
-  {
-    static MutexLock::baton_type baton;
-
-    return baton;
-  }
+  static MutexLock::baton_type baton( );
 
   static value_type get( key_type );
+
+  static thread_registry_type storage( );
 };
 
+SINGLETON_INSTANCE_DEFINITION( LDASTools::AL::SingletonHolder< ::thread_registry > )
+
 void thread_registry::
 Add( thread_registry::key_type Key, thread_registry::value_type Value )
 {
@@ -134,6 +129,18 @@ get( thread_registry::key_type Key )
   return pos->second;
 }
 
+inline thread_registry::thread_registry_type thread_registry::
+storage( )
+{
+  return Instance( ).m_storage;
+}
+
+inline MutexLock::baton_type thread_registry::
+baton( )
+{
+  return Instance( ).__baton__;
+}
+
 namespace LDASTools
 {
   namespace AL
